<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Dreceres ocultes</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Aquestes dreceres de teclat de codi font s&apos;anul·laran si també s&apos;assignen a altres accions a Preferències →Dreceres.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Drecera</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Tanca la finestra o surt del mode de pantalla completa</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Dreta</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Imatge següent</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Espai</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>Fi</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Darrera imatge</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Esquerra</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Imatge anterior</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Retrocés</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Inici</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Primera imatge</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="94"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Inicia a pantalla completa (pot ser útil amb els gestors de finestres en mosaic)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="102"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Fes una captura de pantalla (obsolet, si us plau useu el screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>DIR</source>
        <translation>DIR</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Feu una captura de pantalla i deseu-la al directori sense mostrar la interfície gràfica (obsolet, useu screengrab en lloc seu)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="117"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FITXER1, FITXER2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>resposta d&apos;error desconeguda</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>resposta d&apos;error desconeguda</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>A simple and fast image viewer</source>
        <translation>Un visualitzador d&apos;imatges senzill i ràpid</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>2013-2021</source>
        <translation>2013-2021</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>LXQt Project</source>
        <translation>LXQt Project</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Development: </source>
        <translation>Desenvolupament: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="288"/>
        <source>Author: </source>
        <translation>Autor: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Open File</source>
        <translation>Obre un fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>Image files (%1)</source>
        <translation>Fitxers d&apos;imatges (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>Open directory</source>
        <translation>Obre un directori</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Save File</source>
        <translation>Desa el fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (s&apos;està carregant...) - Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="853"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (ha fallat la càrrega) - Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="859"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1302"/>
        <source>Thumbnails</source>
        <translation>Miniatures</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>EXIF Data</source>
        <translation>Dades EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Neteja</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Utilitzeu una tecla modificadora per esborrar 
una drecera en el mode d&apos;edició.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="213"/>
        <source>Bottom</source>
        <translation>A baix</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="214"/>
        <source>Top</source>
        <translation>A dalt</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Left</source>
        <translation>Esquerra</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="341"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Avís: S&apos;ha detectat una drecera ambigua!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="358"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;No s&apos;accepta la drecera ambigua.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>No es pot desar amb aquest format d&apos;imatge!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Mida:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Camí:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="50"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="51"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="134"/>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="147"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="683"/>
        <source>Annotations Toolbar</source>
        <translation>Barra d&apos;eines d&apos;anotacions</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>&amp;About</source>
        <translation>&amp;Quant a</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>&amp;Save</source>
        <translation>De&amp;sa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Save &amp;As</source>
        <translation>&amp;Anomena i desa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;In</source>
        <translation>Ampl&amp;ia el zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>Zoom &amp;Out</source>
        <translation>Redueix el z&amp;oom</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copia al porta-retalls</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Next File</source>
        <translation>Fitxer següent</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Previous File</source>
        <translation>Fitxer anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>PgDown</source>
        <translation>Re Pàg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Obre &amp;amb...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>Fitxers oberts &amp;recentment</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Sorting</source>
        <translation>Ordenació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Dreceres &amp;ocultes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Open…</source>
        <translation>&amp;Obre…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Reload File</source>
        <translation>To&amp;rna a carregar el fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>PgUp</source>
        <translation>Re Pàg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Original Size</source>
        <translation>Mida original</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>&amp;Fit</source>
        <translation>A&amp;justa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>Gi&amp;ra en sentit horari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>R</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Gira en sentit anti&amp;horari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>L</source>
        <translation>E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>P&amp;references</source>
        <translation>P&amp;referències</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>&amp;Print</source>
        <translation>Im&amp;primeix</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>First File</source>
        <translation>Primer fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Home</source>
        <translation>Inici</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="437"/>
        <source>Last File</source>
        <translation>Últim fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>End</source>
        <translation>Fi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>&amp;New Window</source>
        <translation>Finestra &amp;nova</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="452"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Inverteix &amp;horitzontalment</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>Capture Screenshot</source>
        <translation>Pren una captura de pantalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>F&amp;ull Screen</source>
        <translation>Pantalla c&amp;ompleta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>Flip &amp;Vertically</source>
        <translation>Inverteix &amp;verticalment</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>Enganxa del &amp;porta-retalls</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>&amp;Slide Show</source>
        <translation>Presentació de diapo&amp;sitives</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="518"/>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <source>Show Thumbnails</source>
        <translation>Mostra les miniatures</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>T</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>File Properties</source>
        <translation>Propietats del fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Open &amp;Directory</source>
        <translation>Obre un &amp;directori</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="558"/>
        <source>Upload</source>
        <translation>Puja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="561"/>
        <source>Upload the image</source>
        <translation>Puja la imatge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Show EXIF Data</source>
        <translation>Mostra les dades EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>No Tool</source>
        <translation>Cap eina</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Deselect all drawing tools</source>
        <translation>Desselecciona totes les eines de dibuix</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>Draw Arrow</source>
        <translation>Dibuixa una fletxa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="602"/>
        <source>Draw an arrow</source>
        <translation>Dibuixa una fletxa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="614"/>
        <source>Draw Rectangle</source>
        <translation>Dibuixa un rectangle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Draw a hollow rectangle</source>
        <translation>Dibuixa un rectangle buit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="629"/>
        <source>Draw Circle</source>
        <translation>Dibuixa un cercle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="632"/>
        <source>Draw a hollow circle</source>
        <translation>Dibuixa un cercle buit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="644"/>
        <source>Draw Number</source>
        <translation>Dibuixa un número</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Draw incrementing numbers</source>
        <translation>Dibuixa números de manera incremental</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="658"/>
        <source>Menubar</source>
        <translation>Barra de menú</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <source>&amp;Main Toolbar</source>
        <translation>&amp;Barra d&apos;eines principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <source>Main Toolbar</source>
        <translation>Barra d&apos;eines principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Barra d&apos;eines d&apos;anotacions</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="691"/>
        <location filename="../mainwindow.ui" line="694"/>
        <source>Show Outline</source>
        <translation>Mostra el contorn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="697"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="705"/>
        <source>Copy Pa&amp;th</source>
        <translation>Copia el &amp;camí</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy path</source>
        <translation>Copia el camí</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="716"/>
        <location filename="../mainwindow.ui" line="719"/>
        <source>Rename</source>
        <translation>Canvia el nom</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="722"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="731"/>
        <source>Resize</source>
        <translation>Redimensiona</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="739"/>
        <source>&amp;By File Name</source>
        <translation>&amp;Per nom del fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <source>By File Name</source>
        <translation>Per nom del fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>By &amp;Modification Time</source>
        <translation>Per &amp;data de modificació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>By Modification Time</source>
        <translation>Per data de modificació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="761"/>
        <source>By C&amp;reation Time</source>
        <translation>Per &amp;data de creació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="764"/>
        <source>By Creation Time</source>
        <translation>Per data de creació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="772"/>
        <source>By File &amp;Size</source>
        <translation>Per &amp;la mida del fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>By File Size</source>
        <translation>Per la mida del fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="783"/>
        <source>By File &amp;Type</source>
        <translation>Per tipus de &amp;fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>By File Type</source>
        <translation>Per tipus de fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Vés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>&amp;Visualitza</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>&amp;Edit</source>
        <translation>&amp;Edita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Toolbar</source>
        <translation>Barra d&apos;eines</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferències</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Tema de les icones:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Mida límit del fitxer de miniatures:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Color del fons normal:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Color del fons pantalla completa:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Nombre màxim de fitxers recents:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>Interval per mostrar la diapositiva (segons):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Show image outline by default</source>
        <translation>Mostra el contorn de la imatge per defecte</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Mostra la barra d&apos;eines d&apos;anotacions per defecte</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Fit images when navigating</source>
        <translation>Ajusta les imatges en navegar</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Dimensions de les imatges en miniatura:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Usa la paperera del sistema (sense confirmació)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Mostra l&apos;acoblador de miniatures per defecte</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Mostra l&apos;acoblador de dades Exif per defecte</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Mostra la barra de menús per defecte</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Mostra la barra d&apos;eines principal per defecte</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Imatge</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Smooth images on zooming</source>
        <translation>Suavitza les imatges en ampliar-les</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="264"/>
        <source>Shortcuts</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="283"/>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="288"/>
        <source>Shortcut</source>
        <translation>Drecera</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="296"/>
        <source>Default</source>
        <translation>Per defecte</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>General</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Redimensiona la imatge</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Amplada</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Alçada</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Mida actual:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Nova mida:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Manté la relació d&apos;aspecte</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Pren una captura de pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Regió</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Tota la pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Tan sols la finestra activa</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Captura una àrea de la pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Inclou el cursor del ratolí</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Retard:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Inclou el títol de la finestra i el marc</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Puja</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
</context>
</TS>
